@@ -606,7 +606,7 @@ libc_hidden_proto(unsetenv)
 #ifdef __UCLIBC_DYNAMIC_ATEXIT__
 # define __UCLIBC_MAX_ATEXIT     INT_MAX
 #else
-# define __UCLIBC_MAX_ATEXIT     20
+# define __UCLIBC_MAX_ATEXIT     32
 #endif
 
 
@@ -979,12 +979,18 @@ extern int getpt (void);
 # endif
 #endif
 
-#if 0 /* def __USE_BSD */
+#ifdef __USE_BSD
 /* Put the 1 minute, 5 minute and 15 minute load averages into the first
    NELEM elements of LOADAVG.  Return the number written (never more than
    three, but may be less than NELEM), or -1 if an error occurred.  */
 extern int getloadavg (double __loadavg[], int __nelem)
      __THROW __nonnull ((1));
+
+/* reallocarray() only provided by the malloc-standard implementation */
+#if defined(__MALLOC_STANDARD__)
+extern void *reallocarray (void *__ptr, size_t __m, size_t __n);
+#endif
+
 #endif
 
 #ifdef _LIBC
