@@ -316,6 +316,10 @@ libc_hidden_proto(faccessat)
 # define SEEK_SET	0	/* Seek from beginning of file.  */
 # define SEEK_CUR	1	/* Seek from current position.  */
 # define SEEK_END	2	/* Seek from end of file.  */
+# ifdef __USE_GNU
+#  define SEEK_DATA     3       /* Seek to next data.  */
+#  define SEEK_HOLE     4       /* Seek to next hole.  */
+# endif
 #endif
 
 #if defined __USE_BSD && !defined L_SET
@@ -585,13 +589,11 @@ extern int execve (const char *__path, char *const __argv[],
 		   char *const __envp[]) __THROW __nonnull ((1, 2));
 libc_hidden_proto(execve)
 
-#if 0 /*def __USE_XOPEN2K8*/
 /* Execute the file FD refers to, overlaying the running program image.
    ARGV and ENVP are passed to the new program, as for `execve'.  */
 extern int fexecve (int __fd, char *const __argv[], char *const __envp[])
      __THROW __nonnull ((2));
-#endif
-
+libc_hidden_proto(fexecve)
 
 /* Execute PATH with arguments ARGV and environment from `environ'.  */
 extern int execv (const char *__path, char *const __argv[])
@@ -1248,6 +1250,15 @@ extern void swab (const void *__restrict __from, void *__restrict __to,
 extern char *ctermid (char *__s) __THROW;
 #endif
 
+/* OpenBSD-compatible access to random bytes.
+   May be a cancellation point here, unlike in glibc/musl.  */
+#ifdef _DEFAULT_SOURCE
+# ifndef __getentropy_defined
+extern int getentropy(void *__buf, size_t __len) __nonnull ((1)) __wur;
+#  define __getentropy_defined
+# endif
+#endif
+
 __END_DECLS
 
 
