@@ -204,8 +204,8 @@ FCT (const CHAR *pattern, const CHAR *string, const CHAR *string_end,
 	case L('['):
 	  {
 	    /* Nonzero if the sense of the character class is inverted.  */
-	    CHAR *p_init = p;
-	    CHAR *n_init = n;
+	    const CHAR *p_init = p;
+	    const CHAR *n_init = n;
 	    register int not;
 	    CHAR cold;
 	    UCHAR fn;
@@ -620,7 +620,7 @@ FCT (const CHAR *pattern, const CHAR *string, const CHAR *string_end,
 
 		    if (c == L('-') && *p != L(']'))
 		      {
-#if _LIBC
+#ifdef _LIBC
 			/* We have to find the collation sequence
 			   value for C.  Collation sequence is nothing
 			   we can regularly access.  The sequence
@@ -917,7 +917,6 @@ FCT (const CHAR *pattern, const CHAR *string, const CHAR *string_end,
 		  }
 		else if (c == L('[') && *p == L('.'))
 		  {
-		    ++p;
 		    while (1)
 		      {
 			c = *++p;
