@@ -781,6 +781,7 @@ size_t wcsnrtombs(char *__restrict dst, const wchar_t **__restrict src,
 	size_t count;
 	int incr;
 	char buf[MB_LEN_MAX];
+	(void)ps;
 
 #ifdef __CTYPE_HAS_UTF_8_LOCALES
 	if (ENCODING == __ctype_encoding_utf8) {
@@ -1297,7 +1298,7 @@ iconv_t weak_function iconv_open(const char *tocode, const char *fromcode)
 
 int weak_function iconv_close(iconv_t cd)
 {
-	free(cd);
+	free((void *) cd);
 
 	return 0;
 }
