@@ -10,6 +10,10 @@
 #include <sys/syscall.h>
 #include <sys/timex.h>
 
-#ifdef __NR_clock_adjtime
+#if defined(__UCLIBC_USE_TIME64__) && defined(__NR_clock_adjtime64)
+_syscall2_64(int, clock_adjtime, clockid_t, clock_id, struct timex*, ntx)
+#elif defined(__NR_clock_adjtime)
 _syscall2(int, clock_adjtime, clockid_t, clock_id, struct timex*, ntx)
+#else
+#warning "clock_adjtime syscall is not defined!"
 #endif
