@@ -1,4 +1,3 @@
-/* vi: set sw=4 ts=4: */
 /*
  * rename() for uClibc
  *
@@ -17,6 +16,14 @@ int rename(const char *oldpath, const char *newpath)
 {
 	return renameat(AT_FDCWD, oldpath, AT_FDCWD, newpath);
 }
+#elif defined __NR_renameat2
+# include <fcntl.h>
+int rename(const char *oldpath, const char *newpath)
+{
+	_syscall5(int, renameat2, int, olddfd, const char *, oldpath,
+		  int, newdfd, const char *, newpath, int, flags)
+	return renameat2(AT_FDCWD, oldpath, AT_FDCWD, newpath, 0);
+}
 #else
 _syscall2(int, rename, const char *, oldpath, const char *, newpath)
 #endif
