@@ -53,6 +53,7 @@
 # define O_DIRECT	040000
 # define O_NOATIME	01000000 /* Do not set atime.  */
 # define O_PATH        010000000 /* Resolve pathname but do not open file.  */
+# define O_TMPFILE     020200000 /* Atomically create nameless file.  */
 #endif
 
 #ifdef __USE_LARGEFILE64
@@ -97,11 +98,13 @@
 # define F_SETLEASE	1024	/* Set a lease.	 */
 # define F_GETLEASE	1025	/* Enquire what lease is active.  */
 # define F_NOTIFY	1026	/* Request notfications on a directory.	 */
-# define F_DUPFD_CLOEXEC 1030	/* Duplicate file descriptor with
-				   close-on-exit set on new fd.  */
 # define F_SETPIPE_SZ	1031    /* Set pipe page size array.  */
 # define F_GETPIPE_SZ	1032    /* Get pipe page size array.  */
 #endif
+#if defined __USE_XOPEN2K8 || defined __USE_GNU
+# define F_DUPFD_CLOEXEC 1030	/* Duplicate file descriptor with
+				   close-on-exit set on new fd.  */
+#endif
 
 /* For F_[GET|SET]FD.  */
 #define FD_CLOEXEC	1	/* actually anything with low bit set goes */
@@ -235,3 +238,5 @@ extern ssize_t tee (int __fdin, int __fdout, size_t __len,
 #endif
 __END_DECLS
 
+/* Include generic Linux declarations.  */
+#include <bits/fcntl-linux.h>
