@@ -83,10 +83,10 @@ typedef struct mcontext_t
   } mcontext_t;
 
 /* Userlevel context.  */
-typedef struct ucontext_t
+typedef struct ucontext
   {
     unsigned long int  __uc_flags;
-    struct ucontext_t *uc_link;
+    struct ucontext   *uc_link;
     stack_t            uc_stack;
     sigset_t           uc_sigmask;
     /* There's some padding here to allow sigset_t to be expanded in the
