@@ -4,20 +4,13 @@
  */
 
 #include <features.h>
-#include <bits/wordsize.h>
 
 #define __ASSEMBLY__
-#ifndef __sparc_v9__
 #include <asm/traps.h>
-#endif
 
 /* Is alignment really needed? */
 
-#if __WORDSIZE == 32
-# define ENTRY_ALIGN 4
-#else
-# define ENTRY_ALIGN 2
-#endif
+#define ENTRY_ALIGN 4
 
 #define ENTRY(sym) \
 	.global sym; \
