@@ -14,3 +14,5 @@ typedef struct
 
 extern void *__tls_get_addr (tls_index *ti);
 
+/* Value used for dtv entries for which the allocation is delayed.  */
+#define TLS_DTV_UNALLOCATED    ((void *) -1l)
