@@ -19,9 +19,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-/* Default stack size.  */
-#define ARCH_STACK_DEFAULT_SIZE  (2 * 1024 * 1024)
-
 /* Required stack pointer alignment at beginning.  */
 #define STACK_ALIGN         16
 
