@@ -14,6 +14,11 @@
 
 #include "porting.h"
 
+#if defined(__kvx__)
+#define MATCH_MACHINE(x) (x == EM_KVX)
+#define ELFCLASSM	ELFCLASS64
+#endif
+
 #if defined(__aarch64__)
 #define MATCH_MACHINE(x) (x == EM_AARCH64)
 #define ELFCLASSM	ELFCLASS64
@@ -25,7 +30,12 @@
 #endif
 
 #if defined(__arc__)
-#define MATCH_MACHINE(x) (x == EM_ARCOMPACT)
+#define MATCH_MACHINE(x) (x == EM_ARCOMPACT || x == EM_ARCV2)
+#define ELFCLASSM      ELFCLASS32
+#endif
+
+#if defined(__ARC64_ARCH32__)
+#define MATCH_MACHINE(x) (x == EM_ARCV3_32)
 #define ELFCLASSM      ELFCLASS32
 #endif
 
